@@ -6,8 +6,8 @@
 #
 # maintained by the
 # @author Chart Group at Geodetic Fundamental Station Wettzell (Chart@fs.wettzell.de)
-# @date 2012-01-06
-# @version 2.4.4
+# @date 2014-06-18
+# @version 2.4.7
 #
 #---------------------------------------------------------------------
 # History:
@@ -20,13 +20,13 @@
 
 package Chart::Composite;
 
-use Chart::Base '2.4.4';
+use Chart::Base '2.4.7';
 use GD;
 use Carp;
 use strict;
 
 @Chart::Composite::ISA     = qw(Chart::Base);
-$Chart::Composite::VERSION = '2.4.4';
+$Chart::Composite::VERSION = '2.4.7';
 
 #>>>>>>>>>>>>>>>>>>>>>>>>>>#
 #  public methods go here  #
@@ -602,7 +602,7 @@ sub _draw_top_legend
     }
 
     # mark of the space used
-    $self->{'curr_y_min'} += ( $rows * $row_height ) + $self->{'text_space'} + 2 * $self->{'legend_space'};
+    $self->{'curr_y_min'} += $rows * $row_height + $self->{'text_space'} + 2 * $self->{'legend_space'};
 
     return;
 }
@@ -1066,7 +1066,7 @@ sub _draw_bottom_legend
     }
 
     # mark of the space used
-    $self->{'curr_y_max'} -= ( $rows * $row_height ) + $self->{'text_space'} + 2 * $self->{'legend_space'};
+    $self->{'curr_y_max'} -= ( $rows * $row_height ) + 2 * $self->{'text_space'} + 2 * $self->{'legend_space'};
 
     return;
 }
@@ -1112,6 +1112,12 @@ sub _draw_ticks
     #draw the x ticks again
     if ( $self->true( $self->{'xy_plot'} ) )
     {
+        $self->_find_x_scale;
+        # The following statement is necessary as the
+        # _draw_x_number_ticks() located in Base.pm does nothing know
+        # about different y_tick_label_length variables!
+        # This is a hack here
+        $self->{'y_tick_label_length'} = $self->{'y_tick_label_length1'};
         $self->_draw_x_number_ticks;
     }
     else
